@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +40,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -61,8 +64,8 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 18 "eqn.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 18 "../src/preproc/eqn/eqn.ypp" /* yacc.c:338  */
 
 #include <stdio.h>
 #include <string.h>
@@ -74,13 +77,16 @@ extern int non_empty_flag;
 int yylex();
 void yyerror(const char *);
 
-#line 78 "eqn.cpp" /* yacc.c:339  */
-
+#line 81 "src/preproc/eqn/eqn.cpp" /* yacc.c:338  */
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -94,8 +100,8 @@ void yyerror(const char *);
 
 /* In a future release of Bison, this section will be replaced
    by #include "y.tab.h".  */
-#ifndef YY_YY_Y_TAB_H_INCLUDED
-# define YY_YY_Y_TAB_H_INCLUDED
+#ifndef YY_YY_SRC_PREPROC_EQN_EQN_HPP_INCLUDED
+# define YY_YY_SRC_PREPROC_EQN_EQN_HPP_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -231,10 +237,10 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
-#line 30 "eqn.y" /* yacc.c:355  */
+#line 30 "../src/preproc/eqn/eqn.ypp" /* yacc.c:353  */
 
 	char *str;
 	box *b;
@@ -243,8 +249,10 @@ union YYSTYPE
 	int n;
 	column *col;
 
-#line 247 "eqn.cpp" /* yacc.c:355  */
+#line 253 "src/preproc/eqn/eqn.cpp" /* yacc.c:353  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -254,11 +262,9 @@ extern YYSTYPE yylval;
 
 int yyparse (void);
 
-#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
+#endif /* !YY_YY_SRC_PREPROC_EQN_EQN_HPP_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 262 "eqn.cpp" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -279,13 +285,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -297,7 +303,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -333,15 +339,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -349,7 +346,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -517,7 +514,7 @@ union yyalloc
 #define YYMAXUTOK   315
 
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
    as returned by yylex, without out-of-bounds checking.  */
@@ -876,37 +873,37 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -940,7 +937,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -1073,7 +1070,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1166,6 +1163,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1314,12 +1312,12 @@ yyparse (void)
   yyssp++;
 
  yysetstate:
-  *yyssp = yystate;
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
 #ifdef yyoverflow
       {
@@ -1337,7 +1335,6 @@ yyparse (void)
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
@@ -1371,7 +1368,7 @@ yyparse (void)
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
@@ -1482,19 +1479,19 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 124 "eqn.y" /* yacc.c:1646  */
+#line 124 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].b)->top_level(); non_empty_flag = 1; }
-#line 1488 "eqn.cpp" /* yacc.c:1646  */
+#line 1485 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 4:
-#line 129 "eqn.y" /* yacc.c:1646  */
+#line 129 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[0].b); }
-#line 1494 "eqn.cpp" /* yacc.c:1646  */
+#line 1491 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 5:
-#line 131 "eqn.y" /* yacc.c:1646  */
+#line 131 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     {
 		  list_box *lb = (yyvsp[-1].b)->to_list_box();
 		  if (!lb)
@@ -1502,436 +1499,436 @@ yyreduce:
 		  lb->append((yyvsp[0].b));
 		  (yyval.b) = lb;
 		}
-#line 1506 "eqn.cpp" /* yacc.c:1646  */
+#line 1503 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 6:
-#line 142 "eqn.y" /* yacc.c:1646  */
+#line 142 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[0].b); }
-#line 1512 "eqn.cpp" /* yacc.c:1646  */
+#line 1509 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 7:
-#line 144 "eqn.y" /* yacc.c:1646  */
+#line 144 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_mark_box((yyvsp[0].b)); }
-#line 1518 "eqn.cpp" /* yacc.c:1646  */
+#line 1515 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 8:
-#line 146 "eqn.y" /* yacc.c:1646  */
+#line 146 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_lineup_box((yyvsp[0].b)); }
-#line 1524 "eqn.cpp" /* yacc.c:1646  */
+#line 1521 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 9:
-#line 151 "eqn.y" /* yacc.c:1646  */
+#line 151 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[0].b); }
-#line 1530 "eqn.cpp" /* yacc.c:1646  */
+#line 1527 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 10:
-#line 153 "eqn.y" /* yacc.c:1646  */
+#line 153 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_limit_box((yyvsp[-2].b), 0, (yyvsp[0].b)); }
-#line 1536 "eqn.cpp" /* yacc.c:1646  */
+#line 1533 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 11:
-#line 155 "eqn.y" /* yacc.c:1646  */
+#line 155 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_limit_box((yyvsp[-2].b), (yyvsp[0].b), 0); }
-#line 1542 "eqn.cpp" /* yacc.c:1646  */
+#line 1539 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 12:
-#line 157 "eqn.y" /* yacc.c:1646  */
+#line 157 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_limit_box((yyvsp[-4].b), (yyvsp[-2].b), (yyvsp[0].b)); }
-#line 1548 "eqn.cpp" /* yacc.c:1646  */
+#line 1545 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 13:
-#line 159 "eqn.y" /* yacc.c:1646  */
+#line 159 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_limit_box((yyvsp[-4].b), make_limit_box((yyvsp[-2].b), (yyvsp[0].b), 0), 0); }
-#line 1554 "eqn.cpp" /* yacc.c:1646  */
+#line 1551 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 14:
-#line 164 "eqn.y" /* yacc.c:1646  */
+#line 164 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[0].b); }
-#line 1560 "eqn.cpp" /* yacc.c:1646  */
+#line 1557 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 15:
-#line 166 "eqn.y" /* yacc.c:1646  */
+#line 166 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_sqrt_box((yyvsp[0].b)); }
-#line 1566 "eqn.cpp" /* yacc.c:1646  */
+#line 1563 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 16:
-#line 168 "eqn.y" /* yacc.c:1646  */
+#line 168 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_over_box((yyvsp[-2].b), (yyvsp[0].b)); }
-#line 1572 "eqn.cpp" /* yacc.c:1646  */
+#line 1569 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 17:
-#line 170 "eqn.y" /* yacc.c:1646  */
+#line 170 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_small_over_box((yyvsp[-2].b), (yyvsp[0].b)); }
-#line 1578 "eqn.cpp" /* yacc.c:1646  */
+#line 1575 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 18:
-#line 175 "eqn.y" /* yacc.c:1646  */
+#line 175 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[0].b); }
-#line 1584 "eqn.cpp" /* yacc.c:1646  */
+#line 1581 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 19:
-#line 177 "eqn.y" /* yacc.c:1646  */
+#line 177 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_script_box((yyvsp[-2].b), 0, (yyvsp[0].b)); }
-#line 1590 "eqn.cpp" /* yacc.c:1646  */
+#line 1587 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 20:
-#line 182 "eqn.y" /* yacc.c:1646  */
+#line 182 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[0].b); }
-#line 1596 "eqn.cpp" /* yacc.c:1646  */
+#line 1593 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 21:
-#line 184 "eqn.y" /* yacc.c:1646  */
+#line 184 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_script_box((yyvsp[-2].b), (yyvsp[0].b), 0); }
-#line 1602 "eqn.cpp" /* yacc.c:1646  */
+#line 1599 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 22:
-#line 186 "eqn.y" /* yacc.c:1646  */
+#line 186 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_script_box((yyvsp[-4].b), (yyvsp[-2].b), (yyvsp[0].b)); }
-#line 1608 "eqn.cpp" /* yacc.c:1646  */
+#line 1605 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 23:
-#line 191 "eqn.y" /* yacc.c:1646  */
+#line 191 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = split_text((yyvsp[0].str)); }
-#line 1614 "eqn.cpp" /* yacc.c:1646  */
+#line 1611 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 24:
-#line 193 "eqn.y" /* yacc.c:1646  */
+#line 193 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new quoted_text_box((yyvsp[0].str)); }
-#line 1620 "eqn.cpp" /* yacc.c:1646  */
+#line 1617 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 25:
-#line 195 "eqn.y" /* yacc.c:1646  */
+#line 195 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = split_text((yyvsp[0].str)); }
-#line 1626 "eqn.cpp" /* yacc.c:1646  */
+#line 1623 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 26:
-#line 197 "eqn.y" /* yacc.c:1646  */
+#line 197 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new quoted_text_box((yyvsp[0].str)); }
-#line 1632 "eqn.cpp" /* yacc.c:1646  */
+#line 1629 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 27:
-#line 199 "eqn.y" /* yacc.c:1646  */
+#line 199 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new half_space_box; }
-#line 1638 "eqn.cpp" /* yacc.c:1646  */
+#line 1635 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 28:
-#line 201 "eqn.y" /* yacc.c:1646  */
+#line 201 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new space_box; }
-#line 1644 "eqn.cpp" /* yacc.c:1646  */
+#line 1641 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 29:
-#line 203 "eqn.y" /* yacc.c:1646  */
+#line 203 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new tab_box; }
-#line 1650 "eqn.cpp" /* yacc.c:1646  */
+#line 1647 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 30:
-#line 205 "eqn.y" /* yacc.c:1646  */
+#line 205 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[-1].b); }
-#line 1656 "eqn.cpp" /* yacc.c:1646  */
+#line 1653 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 31:
-#line 207 "eqn.y" /* yacc.c:1646  */
+#line 207 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].pb)->set_alignment(CENTER_ALIGN); (yyval.b) = (yyvsp[0].pb); }
-#line 1662 "eqn.cpp" /* yacc.c:1646  */
+#line 1659 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 32:
-#line 209 "eqn.y" /* yacc.c:1646  */
+#line 209 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].pb)->set_alignment(LEFT_ALIGN); (yyval.b) = (yyvsp[0].pb); }
-#line 1668 "eqn.cpp" /* yacc.c:1646  */
+#line 1665 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 33:
-#line 211 "eqn.y" /* yacc.c:1646  */
+#line 211 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].pb)->set_alignment(RIGHT_ALIGN); (yyval.b) = (yyvsp[0].pb); }
-#line 1674 "eqn.cpp" /* yacc.c:1646  */
+#line 1671 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 34:
-#line 213 "eqn.y" /* yacc.c:1646  */
+#line 213 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].pb)->set_alignment(CENTER_ALIGN); (yyval.b) = (yyvsp[0].pb); }
-#line 1680 "eqn.cpp" /* yacc.c:1646  */
+#line 1677 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 35:
-#line 215 "eqn.y" /* yacc.c:1646  */
+#line 215 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = (yyvsp[-1].mb); }
-#line 1686 "eqn.cpp" /* yacc.c:1646  */
+#line 1683 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 36:
-#line 217 "eqn.y" /* yacc.c:1646  */
+#line 217 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_delim_box((yyvsp[-3].str), (yyvsp[-2].b), (yyvsp[0].str)); }
-#line 1692 "eqn.cpp" /* yacc.c:1646  */
+#line 1689 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 37:
-#line 219 "eqn.y" /* yacc.c:1646  */
+#line 219 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_delim_box((yyvsp[-1].str), (yyvsp[0].b), 0); }
-#line 1698 "eqn.cpp" /* yacc.c:1646  */
+#line 1695 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 38:
-#line 221 "eqn.y" /* yacc.c:1646  */
+#line 221 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_overline_box((yyvsp[-1].b)); }
-#line 1704 "eqn.cpp" /* yacc.c:1646  */
+#line 1701 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 39:
-#line 223 "eqn.y" /* yacc.c:1646  */
+#line 223 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_underline_box((yyvsp[-1].b)); }
-#line 1710 "eqn.cpp" /* yacc.c:1646  */
+#line 1707 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 40:
-#line 225 "eqn.y" /* yacc.c:1646  */
+#line 225 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_prime_box((yyvsp[-1].b)); }
-#line 1716 "eqn.cpp" /* yacc.c:1646  */
+#line 1713 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 41:
-#line 227 "eqn.y" /* yacc.c:1646  */
+#line 227 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_accent_box((yyvsp[-2].b), (yyvsp[0].b)); }
-#line 1722 "eqn.cpp" /* yacc.c:1646  */
+#line 1719 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 42:
-#line 229 "eqn.y" /* yacc.c:1646  */
+#line 229 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_uaccent_box((yyvsp[-2].b), (yyvsp[0].b)); }
-#line 1728 "eqn.cpp" /* yacc.c:1646  */
+#line 1725 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 43:
-#line 231 "eqn.y" /* yacc.c:1646  */
+#line 231 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new font_box(strsave(get_grfont()), (yyvsp[0].b)); }
-#line 1734 "eqn.cpp" /* yacc.c:1646  */
+#line 1731 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 44:
-#line 233 "eqn.y" /* yacc.c:1646  */
+#line 233 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new font_box(strsave(get_gbfont()), (yyvsp[0].b)); }
-#line 1740 "eqn.cpp" /* yacc.c:1646  */
+#line 1737 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 45:
-#line 235 "eqn.y" /* yacc.c:1646  */
+#line 235 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new font_box(strsave(get_gfont()), (yyvsp[0].b)); }
-#line 1746 "eqn.cpp" /* yacc.c:1646  */
+#line 1743 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 46:
-#line 237 "eqn.y" /* yacc.c:1646  */
+#line 237 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new fat_box((yyvsp[0].b)); }
-#line 1752 "eqn.cpp" /* yacc.c:1646  */
+#line 1749 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 47:
-#line 239 "eqn.y" /* yacc.c:1646  */
+#line 239 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new font_box((yyvsp[-1].str), (yyvsp[0].b)); }
-#line 1758 "eqn.cpp" /* yacc.c:1646  */
+#line 1755 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 48:
-#line 241 "eqn.y" /* yacc.c:1646  */
+#line 241 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new size_box((yyvsp[-1].str), (yyvsp[0].b)); }
-#line 1764 "eqn.cpp" /* yacc.c:1646  */
+#line 1761 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 49:
-#line 243 "eqn.y" /* yacc.c:1646  */
+#line 243 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new hmotion_box((yyvsp[-1].n), (yyvsp[0].b)); }
-#line 1770 "eqn.cpp" /* yacc.c:1646  */
+#line 1767 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 50:
-#line 245 "eqn.y" /* yacc.c:1646  */
+#line 245 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new hmotion_box(-(yyvsp[-1].n), (yyvsp[0].b)); }
-#line 1776 "eqn.cpp" /* yacc.c:1646  */
+#line 1773 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 51:
-#line 247 "eqn.y" /* yacc.c:1646  */
+#line 247 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new vmotion_box((yyvsp[-1].n), (yyvsp[0].b)); }
-#line 1782 "eqn.cpp" /* yacc.c:1646  */
+#line 1779 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 52:
-#line 249 "eqn.y" /* yacc.c:1646  */
+#line 249 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new vmotion_box(-(yyvsp[-1].n), (yyvsp[0].b)); }
-#line 1788 "eqn.cpp" /* yacc.c:1646  */
+#line 1785 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 53:
-#line 251 "eqn.y" /* yacc.c:1646  */
+#line 251 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].b)->set_spacing_type((yyvsp[-1].str)); (yyval.b) = (yyvsp[0].b); }
-#line 1794 "eqn.cpp" /* yacc.c:1646  */
+#line 1791 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 54:
-#line 253 "eqn.y" /* yacc.c:1646  */
+#line 253 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = new vcenter_box((yyvsp[0].b)); }
-#line 1800 "eqn.cpp" /* yacc.c:1646  */
+#line 1797 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 55:
-#line 255 "eqn.y" /* yacc.c:1646  */
+#line 255 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.b) = make_special_box((yyvsp[-1].str), (yyvsp[0].b)); }
-#line 1806 "eqn.cpp" /* yacc.c:1646  */
+#line 1803 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 56:
-#line 260 "eqn.y" /* yacc.c:1646  */
+#line 260 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     {
 		  int n;
 		  if (sscanf((yyvsp[0].str), "%d", &n) == 1)
 		    (yyval.n) = n;
 		  a_delete (yyvsp[0].str);
 		}
-#line 1817 "eqn.cpp" /* yacc.c:1646  */
+#line 1814 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 57:
-#line 270 "eqn.y" /* yacc.c:1646  */
+#line 270 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.pb) = new pile_box((yyvsp[0].b)); }
-#line 1823 "eqn.cpp" /* yacc.c:1646  */
+#line 1820 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 58:
-#line 272 "eqn.y" /* yacc.c:1646  */
+#line 272 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[-2].pb)->append((yyvsp[0].b)); (yyval.pb) = (yyvsp[-2].pb); }
-#line 1829 "eqn.cpp" /* yacc.c:1646  */
+#line 1826 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 59:
-#line 277 "eqn.y" /* yacc.c:1646  */
+#line 277 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.pb) = (yyvsp[-1].pb); }
-#line 1835 "eqn.cpp" /* yacc.c:1646  */
+#line 1832 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 60:
-#line 279 "eqn.y" /* yacc.c:1646  */
+#line 279 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[-1].pb)->set_space((yyvsp[-3].n)); (yyval.pb) = (yyvsp[-1].pb); }
-#line 1841 "eqn.cpp" /* yacc.c:1646  */
+#line 1838 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 61:
-#line 284 "eqn.y" /* yacc.c:1646  */
+#line 284 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.mb) = new matrix_box((yyvsp[0].col)); }
-#line 1847 "eqn.cpp" /* yacc.c:1646  */
+#line 1844 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 62:
-#line 286 "eqn.y" /* yacc.c:1646  */
+#line 286 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[-1].mb)->append((yyvsp[0].col)); (yyval.mb) = (yyvsp[-1].mb); }
-#line 1853 "eqn.cpp" /* yacc.c:1646  */
+#line 1850 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 63:
-#line 291 "eqn.y" /* yacc.c:1646  */
+#line 291 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.col) = new column((yyvsp[0].b)); }
-#line 1859 "eqn.cpp" /* yacc.c:1646  */
+#line 1856 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 64:
-#line 293 "eqn.y" /* yacc.c:1646  */
+#line 293 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[-2].col)->append((yyvsp[0].b)); (yyval.col) = (yyvsp[-2].col); }
-#line 1865 "eqn.cpp" /* yacc.c:1646  */
+#line 1862 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 65:
-#line 298 "eqn.y" /* yacc.c:1646  */
+#line 298 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.col) = (yyvsp[-1].col); }
-#line 1871 "eqn.cpp" /* yacc.c:1646  */
+#line 1868 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 66:
-#line 300 "eqn.y" /* yacc.c:1646  */
+#line 300 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[-1].col)->set_space((yyvsp[-3].n)); (yyval.col) = (yyvsp[-1].col); }
-#line 1877 "eqn.cpp" /* yacc.c:1646  */
+#line 1874 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 67:
-#line 305 "eqn.y" /* yacc.c:1646  */
+#line 305 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].col)->set_alignment(CENTER_ALIGN); (yyval.col) = (yyvsp[0].col); }
-#line 1883 "eqn.cpp" /* yacc.c:1646  */
+#line 1880 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 68:
-#line 307 "eqn.y" /* yacc.c:1646  */
+#line 307 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].col)->set_alignment(LEFT_ALIGN); (yyval.col) = (yyvsp[0].col); }
-#line 1889 "eqn.cpp" /* yacc.c:1646  */
+#line 1886 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 69:
-#line 309 "eqn.y" /* yacc.c:1646  */
+#line 309 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].col)->set_alignment(RIGHT_ALIGN); (yyval.col) = (yyvsp[0].col); }
-#line 1895 "eqn.cpp" /* yacc.c:1646  */
+#line 1892 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 70:
-#line 311 "eqn.y" /* yacc.c:1646  */
+#line 311 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyvsp[0].col)->set_alignment(CENTER_ALIGN); (yyval.col) = (yyvsp[0].col); }
-#line 1901 "eqn.cpp" /* yacc.c:1646  */
+#line 1898 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 71:
-#line 315 "eqn.y" /* yacc.c:1646  */
+#line 315 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.str) = (yyvsp[0].str); }
-#line 1907 "eqn.cpp" /* yacc.c:1646  */
+#line 1904 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 72:
-#line 317 "eqn.y" /* yacc.c:1646  */
+#line 317 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.str) = (yyvsp[0].str); }
-#line 1913 "eqn.cpp" /* yacc.c:1646  */
+#line 1910 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 73:
-#line 322 "eqn.y" /* yacc.c:1646  */
+#line 322 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.str) = (yyvsp[0].str); }
-#line 1919 "eqn.cpp" /* yacc.c:1646  */
+#line 1916 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 74:
-#line 324 "eqn.y" /* yacc.c:1646  */
+#line 324 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.str) = strsave("{"); }
-#line 1925 "eqn.cpp" /* yacc.c:1646  */
+#line 1922 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
   case 75:
-#line 326 "eqn.y" /* yacc.c:1646  */
+#line 326 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1645  */
     { (yyval.str) = strsave("}"); }
-#line 1931 "eqn.cpp" /* yacc.c:1646  */
+#line 1928 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
     break;
 
 
-#line 1935 "eqn.cpp" /* yacc.c:1646  */
+#line 1932 "src/preproc/eqn/eqn.cpp" /* yacc.c:1645  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1956,14 +1953,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -2159,5 +2155,5 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 329 "eqn.y" /* yacc.c:1906  */
+#line 329 "../src/preproc/eqn/eqn.ypp" /* yacc.c:1903  */
 
